@@ -4,6 +4,8 @@ import autopep8
 import pkg_resources
 from grpc.tools import protoc
 
+_proto_path: str = "./../../../../../proto"
+
 
 def generate_files():
     protoc.main(
@@ -11,19 +13,19 @@ def generate_files():
             "",
             "-I{}".format(pkg_resources.resource_filename('grpc_tools',
                                                           '_proto')),
-            "-I./../../../../../proto/LibcToManageContainer",
-            "-I./../../../../../proto",
+            f"-I{_proto_path}/LibcToManageContainer",
+            f"-I{_proto_path}",
             "--python_out=.",
             "--grpc_python_out=.",
-            "./../../../../../proto/LibcToManageContainer/libc_to_manage.proto",
+            f"{_proto_path}/LibcToManageContainer/libc_to_manage.proto",
         )
     )
     protoc.main(
         (
             "",
-            "-I./../../../../../proto",
+            f"-I{_proto_path}",
             "--python_out=.",
-            "./../../../../../proto/common_types/common_types.proto",
+            f"{_proto_path}/common_types/common_types.proto",
         )
     )
 
@@ -35,6 +37,7 @@ def format_files():
 
 
 if __name__ == '__main__':
+    print(f"path: `{_proto_path}`")
     generate_files()
     print("generate finished")
     format_files()
